@@ -2,7 +2,7 @@
 sentry.plugins.bases.issue
 ~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 from sentry.conf import settings
@@ -14,6 +14,7 @@ from django.utils.html import escape
 from django.utils.safestring import mark_safe
 from social_auth.models import UserSocialAuth
 from sentry.utils.auth import get_auth_providers
+from sentry.utils.http import absolute_uri
 
 
 class NewIssueForm(forms.Form):
@@ -42,7 +43,7 @@ class IssuePlugin(Plugin):
 
     def _get_group_description(self, request, group, event):
         output = [
-            request.build_absolute_uri(reverse('sentry-group', kwargs={
+            absolute_uri(reverse('sentry-group', kwargs={
                 'project_id': group.project.slug,
                 'team_slug': group.team.slug,
                 'group_id': group.id,
