@@ -99,6 +99,7 @@
 
             this.control = $('a[data-action=pause]');
             this.updateStreamOptions();
+            this.initFilters();
 
             this.control.click(_.bind(function(e){
                 e.preventDefault();
@@ -112,6 +113,56 @@
             });
         },
 
+        initFilters: function(){
+            $('.filter').each(_.bind(function(_, el){
+                var $filter = $(el);
+                var $input = $filter.find('input[type=text]');
+                if ($input.length > 0) {
+                    $input.select2({
+                        initSelection: function (el, callback) {
+                            var $el = $(el);
+                            callback({id: $el.val(), text: $el.val()});
+                        },
+                        allowClear: true,
+                        minimumInputLength: 3,
+                        ajax: {
+                            url: this.getSearchTagsUrl(),
+                            dataType: 'json',
+                            data: function (term, page) {
+                                return {
+                                    query: term,
+                                    quietMillis: 300,
+                                    name: $input.attr('name'),
+                                    limit: 10
+                                };
+                            },
+                            results: function (data, page) {
+                                var results = [];
+                                $(data.results).each(function(_, val){
+                                    results.push({
+                                        id: val,
+                                        text: val
+                                    });
+                                });
+                                return {results: results};
+                            }
+                        }
+                    });
+                } else {
+                    $input = $filter.find('select').select2({
+                        allowClear: true
+                    });
+                }
+                if ($input.length > 0) {
+                    $input.on('change', function(e){
+                        var query = app.utils.getQueryParams();
+                        query[e.target.name] = e.val;
+                        window.location.href = '?' + $.param(query);
+                    });
+                }
+            }, this));
+        },
+
         updateStreamOptions: function(){
             if (this.options.realtime){
                 $.removeCookie('pausestream');
@@ -124,6 +175,10 @@
                 this.control.removeClass('realtime-play');
                 this.control.html(this.control.attr('data-play-label'));
             }
+        },
+
+        getSearchTagsUrl: function(){
+            return app.config.urlPrefix + '/api/' + app.config.teamId + '/' + app.config.projectId + '/tags/search/';
         }
 
     });
@@ -180,6 +235,11 @@
                 var event_nav_height;
                 var last_target;
 
+                $window.resize(function(){
+                    event_nav_height = $event_nav.find('.nav').outerHeight();
+                    $event_nav.height(event_nav_height + 'px');
+                }).resize();
+
                 $nav_links.click(function(e){
                     var $el = $(this);
                     var target = $(this.hash);
@@ -187,9 +247,13 @@
                     $el.parent().addClass('active').siblings().removeClass('active');
 
                     $('html,body').animate({
-                        scrollTop: $(target).position().top + event_nav_height
+                        scrollTop: target.position().top + event_nav_height
                     }, 'fast');
 
+                    if (history.pushState) {
+                        history.pushState({}, '', this.hash);
+                    }
+
                     e.preventDefault();
                 }).each(function(){
                     if (this.hash.length > 1 && $(this.hash).length) {
@@ -197,75 +261,52 @@
                     }
                 });
 
-                $window.resize(function(){
-                    event_nav_height = $event_nav.find('.nav').outerHeight();
-                    $event_nav.height(event_nav_height + 'px');
-                }).resize();
-
+                var resizeTimer;
                 $window.scroll(function(){
-                    // Change fixed nav if needed
-                    if ($window.scrollTop() > scroll_offset) {
-                        if (!$event_nav.hasClass('fixed')) {
-                            $event_nav.addClass('fixed');
-                        }
-                    } else if ($event_nav.hasClass('fixed')) {
-                        $event_nav.removeClass('fixed');
-                    }
-
-                    if ($nav_targets.length) {
-                        // Get container scroll position
-                        var from_top = $window.scrollTop() + event_nav_height + 20;
-                       
-                        // Get id of current scroll item
-                        var cur = $.map($nav_targets, function(hash){
-                            if ($(hash).offset().top < from_top) {
-                                return hash;
+                    clearTimeout(resizeTimer);
+                    resizeTimer = setTimeout(function(){
+                        // Change fixed nav if needed
+                        if ($window.scrollTop() > scroll_offset) {
+                            if (!$event_nav.hasClass('fixed')) {
+                                $event_nav.addClass('fixed');
                             }
-                        });
-
-                        // Get the id of the current element
-                        var target = cur ? cur[cur.length - 1] : null;
-
-                        if (!target) {
-                            target = $nav_targets[0];
+                        } else if ($event_nav.hasClass('fixed')) {
+                            $event_nav.removeClass('fixed');
                         }
 
-                        if (last_target !== target) {
-                           last_target = target;
+                        if ($nav_targets.length) {
+                            // Get container scroll position
+                            var from_top = $window.scrollTop() + event_nav_height + 20;
 
-                           // Set/remove active class
-                           $nav_links
-                             .parent().removeClass("active")
-                             .end().filter("[href=" + target + "]").parent().addClass("active");
-                        }  
-                    }
+                            // Get id of current scroll item
+                            var cur = $.map($nav_targets, function(hash){
+                                if ($(hash).offset().top < from_top) {
+                                    return hash;
+                                }
+                            });
+
+                            // Get the id of the current element
+                            var target = cur ? cur[cur.length - 1] : null;
+
+                            if (!target) {
+                                target = $nav_targets[0];
+                            }
+
+                            if (last_target !== target) {
+                               last_target = target;
+
+                               // Set/remove active class
+                               $nav_links
+                                 .parent().removeClass("active")
+                                 .end().filter("[href=" + target + "]").parent().addClass("active");
+                            }
+                        }
+                    }, 1);
                 }).scroll();
             }
         }
     });
 
-    app.NewProjectPage = BasePage.extend({
-
-        initialize: function(data){
-            this.el = $(data.el);
-
-            BasePage.prototype.initialize.call(this, data);
-
-            if (this.options.canSelectTeam && this.options.canCreateTeam) {
-                $('#new_team').hide();
-                $('a[rel="create-new-team"]').click(function(){
-                    $('#new_team').show();
-                    $('#select_team').hide();
-                });
-                $('a[rel="select-team"]').click(function(){
-                    $('#new_team').hide();
-                    $('#select_team').show();
-                });
-            }
-        }
-
-    });
-
     app.WallPage = BasePage.extend({
 
         initialize: function(){
@@ -352,6 +393,116 @@
 
     });
 
+    app.AddTeamMemberPage = BasePage.extend({
+        initialize: function(data){
+            BasePage.prototype.initialize.call(this, data);
+
+            app.utils.makeSearchableUsersInput('form input[name=add-user]');
+        }
+    });
+
+    app.AccessGroupMembersPage = BasePage.extend({
+        initialize: function(data){
+            BasePage.prototype.initialize.call(this, data);
+
+            app.utils.makeSearchableUsersInput('form input[name=user]');
+        }
+    });
+
+    app.AccessGroupProjectsPage = BasePage.extend({
+        initialize: function(data){
+            BasePage.prototype.initialize.call(this, data);
+
+            app.utils.makeSearchableProjectsInput('form input[name=project]');
+        }
+    });
+
+    app.TeamDetailsPage = BasePage.extend({
+        initialize: function(data){
+            BasePage.prototype.initialize.call(this, data);
+
+            app.utils.makeSearchableUsersInput('form input[name=owner]');
+        }
+    });
+
+    app.ProjectDetailsPage = BasePage.extend({
+        initialize: function initialize(data){
+            BasePage.prototype.initialize.call(this, data);
+
+            app.utils.makeSearchableUsersInput('form input[name=owner]');
+
+            $("input[type=range]").each(_.bind(function loop(n, el){
+                var $el = $(el),
+                    min = parseInt($el.attr('min'), 10),
+                    max = parseInt($el.attr('max'), 10),
+                    step = parseInt($el.attr('step'), 10),
+                    values = [],
+                    $value = $('<span class="value"></span>');
+
+                var i = min;
+                while (i <= max) {
+                    values.push(i);
+                    if (i < 12) {
+                        i += 1;
+                    } else if (i < 24) {
+                        i += 3;
+                    } else if (i < 36) {
+                        i += 6;
+                    } else if (i < 48) {
+                        i += 12;
+                    } else {
+                        i += 24;
+                    }
+                }
+
+                $el.on("slider:ready", _.bind(function sliderready(event, data) {
+                    $value.appendTo(data.el);
+                    $value.html(this.formatHours(data.value));
+                }, this)).on("slider:changed", _.bind(function sliderchanged(event, data) {
+                    $value.html(this.formatHours(data.value));
+                }, this)).simpleSlider({
+                    range: [min, max],
+                    step: step,
+                    allowedValues: values,
+                    snap: true
+                });
+            }, this));
+        },
+
+        formatHours: function formatHours(val) {
+            val = parseInt(val, 10);
+            if (val === 0) {
+                return 'Disabled';
+            } else if (val > 23 && val % 24 === 0) {
+                val = (val / 24);
+                return val + ' day' + (val != 1 ? 's' : '');
+            }
+            return val + ' hour' + (val != 1 ? 's' : '');
+        }
+    });
+
+    app.NewProjectPage = BasePage.extend({
+
+        initialize: function(data){
+            this.el = $(data.el);
+
+            BasePage.prototype.initialize.call(this, data);
+
+            if (this.options.canSelectTeam && this.options.canCreateTeam) {
+                $('#new_team').hide();
+                $('a[rel="create-new-team"]').click(function(){
+                    $('#new_team').show();
+                    $('#select_team').hide();
+                });
+                $('a[rel="select-team"]').click(function(){
+                    $('#new_team').hide();
+                    $('#select_team').show();
+                });
+            }
+        }
+
+    });
+
     Backbone.sync = function(method, model, success, error){
         success();
     };
