@@ -134,6 +134,79 @@
                 $link.html($link.attr('data-collapse-label'));
             else
                 $link.html($link.attr('data-expand-label'));
+        },
+
+        getSearchUsersUrl: function(){
+            return app.config.urlPrefix + '/api/' + app.config.teamId + '/users/search/';
+        },
+
+        getSearchProjectsUrl: function(){
+            return app.config.urlPrefix + '/api/' + app.config.teamId + '/projects/search/';
+        },
+
+        makeSearchableInput: function(el, url, callback) {
+            $(el).select2({
+                allowClear: true,
+                width: 'element',
+                initSelection: function (el, callback) {
+                    var $el = $(el);
+                    callback({id: $el.val(), text: $el.val()});
+                },
+                ajax: {
+                    url: url,
+                    dataType: 'json',
+                    data: function (term, page) {
+                        return {
+                            query: term,
+                            limit: 10
+                        };
+                    },
+                    results: function(data, page) {
+                        var results = callback(data);
+                        return {results: callback(data)};
+                    }
+                }
+            });
+        },
+
+        makeSearchableUsersInput: function(el) {
+            this.makeSearchableInput(el, this.getSearchUsersUrl(), function(data){
+                var results = [];
+                $(data.results).each(function(_, val){
+                    var label;
+                    if (val.first_name) {
+                        label = val.first_name + ' &mdash; ' + val.username;
+                    } else {
+                        label = val.username;
+                    }
+                    label += '<br>' + val.email;
+                    results.push({
+                        id: val.username,
+                        text: label
+                    });
+                });
+
+                if ($(results).filter(function(){
+                    return this.id.localeCompare(data.query) === 0;
+                }).length === 0) {
+                    results.push({id:data.query, text:data.query});
+                }
+
+                return results;
+            });
+        },
+
+        makeSearchableProjectsInput: function(el) {
+            this.makeSearchableInput(el, this.getSearchProjectsUrl(), function(data){
+                var results = [];
+                $(data.results).each(function(_, val){
+                    results.push({
+                        id: val.slug,
+                        text: val.name + '<br>' + val.slug
+                    });
+                });
+                return results;
+            });
         }
 
     };
