@@ -2,7 +2,7 @@
 sentry.tasks.cleanup
 ~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -10,7 +10,7 @@ from celery.task import task
 
 
 @task(ignore_result=True)
-def cleanup(days=30, project=None, **kwargs):
+def cleanup(days=30, project=None, chunk_size=1000, **kwargs):
     """
     Deletes a portion of the trailing data in Sentry based on
     their creation dates. For example, if ``days`` is 30, this
@@ -23,10 +23,10 @@ def cleanup(days=30, project=None, **kwargs):
 
     from django.utils import timezone
 
+    # TODO: FilterKey and GroupTagKey need cleaned up
     from sentry.models import (Group, Event, GroupCountByMinute,
-        GroupTag, FilterKey, FilterValue, ProjectCountByMinute,
+        GroupTag, FilterValue, ProjectCountByMinute, Alert,
         SearchDocument, Activity, AffectedUserByGroup, LostPasswordHash)
-    from sentry.utils.query import RangeQuerySetWrapper
 
     GENERIC_DELETES = (
         (SearchDocument, 'date_changed'),
@@ -36,6 +36,8 @@ def cleanup(days=30, project=None, **kwargs):
         (Event, 'datetime'),
         (Activity, 'datetime'),
         (AffectedUserByGroup, 'last_seen'),
+        (FilterValue, 'last_seen'),
+        (Alert, 'datetime'),
 
         # Group should probably be last
         (Group, 'last_seen'),
@@ -52,38 +54,12 @@ def cleanup(days=30, project=None, **kwargs):
         if project:
             qs = qs.filter(project=project)
         # XXX: we step through because the deletion collector will pull all relations into memory
-        for obj in RangeQuerySetWrapper(qs):
-            log.info("Removing %r", obj)
-            obj.delete()
+        while qs.exists():
+            for obj in list(qs[:chunk_size]):
+                log.info("Removing %r", obj)
+                obj.delete()
 
     log.info("Removing expired values for %r", LostPasswordHash)
     LostPasswordHash.objects.filter(
         date_added__lte=timezone.now() - datetime.timedelta(days=1)
     ).delete()
-
-    # We'll need this to confirm deletion of FilterKey and Filtervalue objects.
-    mqs = GroupTag.objects.all()
-    if project:
-        mqs = mqs.filter(project=project)
-
-    # FilterKey
-    log.info("Removing %r for days=%s project=%r", FilterKey, days, project or '*')
-    qs = FilterKey.objects.all()
-    if project:
-        qs = qs.filter(project=project)
-    for obj in RangeQuerySetWrapper(qs):
-        if not mqs.filter(key=obj.key).exists():
-            log.info("Removing unused filter %s=*", obj.key,)
-            qs.filter(key=obj.key).delete()
-            obj.delete()
-
-    # FilterValue
-    log.info("Removing %r for days=%s project=%r", FilterValue, days, project or '*')
-    qs = FilterValue.objects.all()
-    if project:
-        qs = qs.filter(project=project)
-    for obj in RangeQuerySetWrapper(qs):
-        if not mqs.filter(key=obj.key, value=obj.value).exists():
-            log.info("Removing unused filter %s=%s", obj.key, obj.value)
-            qs.filter(key=obj.key, value=obj.value).delete()
-            obj.delete()
